SurveyQuestionsInner class abstract
SurveyQuestionsInner
Properties:
typenamestatevisibleuseDisplayValuesInDynamicTextsvisibleIfwidthminWidthmaxWidthstartWithNewLineindentpagetitletitleLocationdescriptiondescriptionLocationhideNumbervalueNameenableIfdefaultValuedefaultValueExpressioncorrectAnswerclearIfInvisibleisRequiredrequiredIfrequiredErrorTextreadOnlyvalidatorsbindingsrenderAsshowCommentAreacommentTextcommentPlaceholderchoicesFromQuestionchoiceschoicesFromQuestionModechoicesOrderchoicesByUrlhideIfChoicesEmptychoicesVisibleIfchoicesEnableIfseparateSpecialChoicesshowOtherItemshowNoneItemotherPlaceholdernoneTextotherTextotherErrorTextstoreOthersAsCommentcolCountshowSelectAllItemmaxSelectedChoicesminSelectedChoicesselectAllTextvaluePropertyNameitemComponentplaceholderallowClearsearchEnabledchoicesLazyLoadEnabledchoicesLazyLoadPageSizehideSelectedItemscloseOnSelectlongTapselectToRankEnabledselectToRankAreasLayoutshowClearButtonoptionsCaptioncontentModeimageFitimageHeightimageWidthminImageWidthminImageHeightmaxImageWidthmaxImageHeightshowLabelmultiSelectchoicesMinchoicesMaxchoicesStepautocompleteinputFieldComponentcolumnsVisibleIfrowsVisibleIfcolumnMinWidthshowHeaderverticalAlignalternateRowscolumnscolumnLayoutdetailElementsdetailPanelModehorizontalScrollkeyDuplicationErrorcellTypecolumnColCountallowAdaptiveActionsrowsrowTitleWidthtotalTexthideIfRowsEmptyallowAddRowsallowRemoveRowsrowCountminRowCountmaxRowCountkeyNamedefaultRowValuedefaultValueFromLastRowconfirmDeleteconfirmDeleteTextaddRowLocationaddRowTextremoveRowTexthideColumnsIfEmptyemptyRowsTextdetailPanelShowOnAddingallowRowsDragAndDropcellsrowsOrderisAllRowRequiredexpressionformatdisplayStylecurrencymaximumFractionDigitsminimumFractionDigitsuseGroupingprecisioninputTypesizetextUpdateMode- min
- max
minValueExpressionmaxValueExpressionminErrorTextmaxErrorTextstepmaxLengthdataListcolsautoGrowallowResizeacceptCarriageReturnitemsitemSizehtmlimageLinkaltTextshowPreviewallowMultipleallowImagesPreviewacceptedTypesstoreDataAsTextwaitForUploadmaxSizeneedConfirmRemoveFileallowCameraAccessrateTypescaleColorModerateColorModeautoGeneraterateCountrateValuesrateMinrateMaxrateStepminRateDescriptionmaxRateDescriptiondisplayRateDescriptionsAsExtremeItemsdisplayModelabellabelTruelabelFalsevalueTruevalueFalsesignatureWidthsignatureHeightheightpenColorbackgroundColordataFormattemplateElementstemplateTitletemplateTabTitletemplateDescriptionnoEntriesTextallowAddPanelallowRemovePanelpanelCountminPanelCountmaxPanelCountdefaultPanelValuedefaultValueFromLastPanelpanelsStatepanelAddTextpanelRemoveTextpanelPrevTextpanelNextTextshowQuestionNumbersshowRangeInProgressrenderModetabAligntemplateTitleLocationtemplateVisibleIfpanelRemoveButtonLocationelementsquestionTitleLocationquestionsOrderquestionsinnerIndentshowNumberquestionStartIndex
- Available extensions
- Annotations
-
- @BuiltValue.new()
Constructors
- SurveyQuestionsInner([void updates(SurveyQuestionsInnerBuilder b)])
-
factory
Properties
- anyOf → AnyOf
-
Any Of Boolean, Buttongroup, Checkbox, Comment, Dropdown, Elementbase, Empty, Expression, File, Html, Image, Imagepicker, Matrix, Matrixdropdown, Matrixdropdownbase, Matrixdynamic, Multipletext, Nonvalue, Panel, Paneldynamic, Radiogroup, Ranking, Rating, Signaturepad, Tagbox, Text, Textbase
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- realElement → Elementbase
-
Available on SurveyQuestionsInner, provided by the SurveyQuestionsInnerExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(SurveyQuestionsInnerBuilder)) → SurveyQuestionsInner -
Rebuilds the instance.
inherited
-
toBuilder(
) → SurveyQuestionsInnerBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SurveyQuestionsInner> -
no setter